@@ -69,7 +69,7 @@ class Plot:
             data = [data]
 
         for d in data:
-            if getattr(d, "plot_map", None) is None:
+            if not hasattr(d, "plot_map"):
                 d = helper(d)
 
             d.plot_map(self.driver)
