@@ -12,10 +12,10 @@ import logging
 
 import eccodes
 
-from climetlab.decorators import dict_args
+# from climetlab.decorators import dict_args
 from climetlab.utils.bbox import BoundingBox
 
-from . import Reader
+from . import MultiReaders, Reader
 
 LOG = logging.getLogger(__name__)
 
@@ -218,12 +218,12 @@ class GRIBFilter:
         return GRIBIterator(self.path)
 
 
-class GRIBMultiFileReader(Reader):
-    def __init__(self, source, readers):
-        super().__init__(source, "/-multi-")
+class MultiGribReaders(MultiReaders):
+    engine = "cfgrib"
+    backend_kwargs = {"squeeze": False}
 
 
-class OLDGRIBReader(Reader):
+class GRIBReader(Reader):
     def __init__(self, source, path):
         super().__init__(source, path)
         self._fields = None
@@ -250,167 +250,14 @@ class OLDGRIBReader(Reader):
     def __len__(self):
         return len(self._items())
 
-    def to_xarray(self):
-        import xarray as xr
+    def to_xarray(self, **kwargs):
+        # So we use the same code
+        return MultiGribReaders([self]).to_xarray(**kwargs)
 
-        params = self.source.cfgrib_options()
-        ds = xr.open_dataset(self.path, engine="cfgrib", **params)
-        return self.source.post_xarray_open_dataset_hook(ds)
-
-    @dict_args
-    def sel(self, **kwargs):
-        return GRIBFilter(self, kwargs)
-
-    def multi_merge(source, readers):
-        return GRIBMultiFileReader(source, readers)
-
-
-class GRIBReader(Reader):
-    def __init__(self, source, paths=None, fields=[], filter=None, unfiltetered=True):
-        super().__init__(source, paths)
-        self._fields = [f for f in fields]
-        self._unfiltetered = unfiltetered
-
-        if paths is not None:
-            if not isinstance(paths, (list, tuple)):
-                paths = [paths]
-            for path in paths:
-                for f in GRIBIterator(path):
-                    self._fields.append(f)
-
-    def __getitem__(self, n):
-        return self._fields[n]
-
-    def __len__(self):
-        return len(self._fields)
-
-    def _attributes(self, names):
-        result = []
-        for field in self:
-            result.append(field._attributes(names))
-        return result
-
-    def multi_merge(source, readers):
-        fields = []
-        paths = []
-        for r in readers:
-            fields += r._fields
-            if isinstance(r.path, (list, tuple)):
-                paths += list(r.path)
-            else:
-                paths.append(r.path)
-
-        return GRIBReader(
-            source,
-            paths=paths,
-            # fields=fields,
-            unfiltetered=all(r._unfiltetered for r in readers),
-        )
-
-    def to_xarray(self):
-        assert self._unfiltetered
-        assert self.path
-
-        import xarray as xr
-
-        params = self.source.cfgrib_options()
-        if isinstance(self.path, (list, tuple)):
-            ds = xr.open_mfdataset(self.path, engine="cfgrib", **params)
-        else:
-            ds = xr.open_dataset(self.path, engine="cfgrib", **params)
-        return self.source.post_xarray_open_dataset_hook(ds)
-
-
-class Field:
-    def __init__(self, field):
-        self.field = field
-
-    def __getitem__(self, key):
-        print("field", key)
-        v = self.field.handle.get(key)
-        return v
-
-
-class FieldSetIndex:
-    def __init__(
-        self,
-        source,
-        *,
-        filter_by_keys={},
-        grib_errors="warn",
-        index_keys=[],
-        read_keys=[],
-        items=None,
-    ):
-        self.source = source
-        self.filter_by_keys = filter_by_keys
-        self.grib_errors = grib_errors
-        self.index_keys = index_keys
-        self.read_keys = read_keys
-        self.items = items
-
-    def __call__(self, *, grib_errors, index_keys, read_keys, **kwargs):
-        return FieldSetIndex(
-            source=self.source,
-            filter_by_keys=self.filter_by_keys,
-            grib_errors=grib_errors,
-            index_keys=index_keys,
-            read_keys=read_keys,
-            items=self.items,
-        )
-
-    def subindex(self, filter_by_keys={}, **kwargs):
-        query = dict(**self.filter_by_keys)
-        query.update(filter_by_keys)
-        query.update(kwargs)
-        return FieldSetIndex(
-            source=self.source,
-            filter_by_keys=query,
-            grib_errors=self.grib_errors,
-            index_keys=self.index_keys,
-            read_keys=self.read_keys,
-            items=self.items,
-        )
-
-    def _valid(self, item):
-        for k, v in self.filter_by_keys.items():
-            if item.get(k) != v:
-                return False
-        return True
-
-    def _valid_items(self):
-        if self.items is None:
-            self.items = self.source._attributes(self.index_keys)
-
-        return [i for i in self.items if self._valid(i)]
-
-    def __getitem__(self, key):
-
-        x = [i[key] for i in self._valid_items()]
-        if None in x:
-            return []
-
-        print("GET", key, x)
-        return list(set(x))
-
-    def getone(self, key):
-        return self[key][0]
-
-    @property
-    def offsets(self):
-        for i, item in enumerate(self._valid_items()):
-            yield item, i
-
-    @property
-    def filestream(self):
-        return self
-
-    @property
-    def path(self):
-        return None
-
-    def first(self):
-        return Field(self.source[0])
+    @classmethod
+    def multi_merge(cls, readers):
+        assert all(isinstance(r, GRIBReader) for r in readers)
+        return MultiGribReaders(readers)
 
 
 def reader(source, path, magic):
