@@ -13,6 +13,7 @@ from importlib import import_module
 
 from climetlab.core.caching import cache_file
 from climetlab.core.plugins import find_plugin, register
+from climetlab.core.settings import SETTINGS
 from climetlab.utils.html import table
 
 
@@ -24,7 +25,10 @@ class SourceLoader:
         return import_module(module, package=__name__).source
 
     def load_entry(self, entry):
-        return entry.load().source
+        entry = entry.load()
+        if callable(entry):
+            return entry
+        return entry.source
 
 
 class SourceMaker:
@@ -89,6 +93,9 @@ class Source:
     def __init__(self, **kwargs):
         self._kwargs = kwargs
 
+    def settings(self, name):
+        return SETTINGS.get(name)
+
     def mutate(self):
         # Give a chance to `multi` to change source
         return self
@@ -127,13 +134,6 @@ class Source:
             return {}
         return self.dataset.read_zarr_options(*args, **kwargs)
 
-    def cfgrib_options(self, *args, **kwargs):
-        if self.dataset is None:
-            return {}
-        return self.dataset.cfgrib_options(*args, **kwargs)
-
-    def post_xarray_open_dataset_hook(self, ds, *args, **kwargs):
-        if self.dataset is None:
-            # print(f'from {self} no self.dataset {self.dataset}, no hook')
-            return ds
-        return self.dataset.post_xarray_open_dataset_hook(ds, *args, **kwargs)
+    @classmethod
+    def multi_merge(cls, sources):
+        return None
