@@ -45,6 +45,9 @@ class FileSource(Source):
     def sel(self, *args, **kwargs):
         return self._reader.sel(*args, **kwargs)
 
+    def plot_map(self, *args, **kwargs):
+        return self._reader.plot_map(*args, **kwargs)
+
     def to_xarray(self, *args, **kwargs):
         return self._reader.to_xarray(*args, **kwargs)
 
@@ -57,12 +60,12 @@ class FileSource(Source):
     def to_metview(self, *args, **kwargs):
         return self._reader.to_metview(*args, **kwargs)
 
-    def multi_merge(sources):
-        f = FileSource()
-        t = type(sources[0]._reader)
-        assert all(type(s._reader) == t for s in sources)
-        f._reader_ = t.multi_merge(f, [a._reader for a in sources])
-        return os.fspath
+    @classmethod
+    def multi_merge(cls, sources):
+        if not all(isinstance(s, FileSource) for s in sources):
+            return None
+        readers = [s._reader for s in sources]
+        return readers[0].multi_merge(readers)
 
     def _attributes(self, names):
         return self._reader._attributes(names)
