@@ -14,24 +14,18 @@ from . import Source
 
 
 class MultiSource(Source):
-    def __init__(self, *sources):
+    def __init__(self, *sources, merger=None):
         if len(sources) == 1 and isinstance(sources[0], list):
             sources = sources[0]
-
+        self.merger = merger
         self.sources = sources
         self._lengths = [None] * len(sources)
 
     def mutate(self):
-        if len(self.sources) == 1:
+        if len(self.sources) == 1 and self.merger is None:
             return self.sources[0].mutate()
         return self
 
-    #     t = type(self.sources[0])
-    #     if all(type(s) == t for s in self.sources):
-    #         return t.multi_merge(self.sources).mutate()
-
-    #     return self
-
     def _set_dataset(self, dataset):
         super()._set_dataset(dataset)
         for s in self.sources:
@@ -53,12 +47,6 @@ class MultiSource(Source):
 
     def sel(self, *args, **kwargs):
         raise NotImplementedError
-        # new_sources = []
-        # for s in self.sources:
-        #     new = s.sel(*args, **kwargs)
-        #     return new_sources.append(new)
-        # merged = self.__class__(self, sources=new_sources)
-        # return merged
 
     def __len__(self):
         return sum(self._length(i) for i, _ in enumerate(self.sources))
@@ -68,9 +56,13 @@ class MultiSource(Source):
             self._lengths[i] = len(self.sources[i])
         return self._lengths[i]
 
-    def to_xarray(self):
+    def to_xarray(self, **kwargs):
         import xarray as xr
 
+        merged = self.sources[0].multi_merge(self.sources)
+        if merged is not None:
+            return merged.to_xarray(merger=self.merger, **kwargs)
+
         arrays = [s.to_xarray() for s in self.sources]
 
         # Get values of scalar coordinates
@@ -82,13 +74,6 @@ class MultiSource(Source):
                     # assert len(vals) == 1, (v, vals)
                     values[v].add(float(vals))
 
-        # for a in arrays:
-        #     print("++++ ======")
-        #     for v in a.variables:
-        #         print(v, [x for x in a[v].dims])
-        #     print("++++ ======")
-        #     print()
-
         # Promote scalar coordinates
         promote = [name for name, count in values.items() if len(count) > 1]
 
@@ -96,7 +81,6 @@ class MultiSource(Source):
             dims = dict(zip(promote, [1] * len(promote)))
             arrays = [a.expand_dims(dims) for a in arrays]
 
-        # return xr.concat(s.to_xarray() for s in self.sources)
         return xr.merge(arrays)
 
 
