@@ -7,6 +7,8 @@
 # nor does it submit to any jurisdiction.
 #
 
+from concurrent.futures import ThreadPoolExecutor
+
 from climetlab.utils.patterns import Pattern
 
 from .multi import MultiSource
@@ -14,13 +16,21 @@ from .url import Url
 
 
 class UrlPattern(MultiSource):
-    def __init__(self, pattern, *args, **kwargs):
+    def __init__(self, pattern, *args, merger=None, **kwargs):
         urls = Pattern(pattern).substitute(*args, **kwargs)
         if not isinstance(urls, list):
             urls = [urls]
 
-        sources = [Url(url) for url in urls]
-        super().__init__(sources)
+        def url_to_source(url):
+            return Url(url)
+
+        with ThreadPoolExecutor(
+            max_workers=self.settings("number-of-download-threads")
+        ) as executor:
+            futures = [executor.submit(url_to_source, url) for url in urls]
+            sources = [f.result() for f in futures]
+
+        super().__init__(sources, merger=merger)
 
 
 source = UrlPattern
