@@ -31,8 +31,45 @@ def bytes_to_string(n):
     return "%g%s" % (int(n * 10 + 0.5) / 10.0, u[i])
 
 
-def consume_args(func, *args, **kwargs):
-    spec = inspect.getfullargspec(func)
+def _dummy(**kwargs):
+    pass
+
+
+def consume_args(func1, func2, *args, **kwargs):
+
+    # print("=====>", args, kwargs)
+
+    if func1 is None:
+        func1 = _dummy
+
+    if func2 is None:
+        func2 = _dummy
+
+    args1 = set()
+    sig1 = inspect.signature(func1)
+    for name, param in sig1.parameters.items():
+        if param.kind not in (param.VAR_POSITIONAL, param.VAR_KEYWORD):
+            args1.add(name)
+
+    # print(f"{func1.__name__}{sig1}")
+
+    args2 = set()
+    sig2 = inspect.signature(func2)
+    for name, param in sig2.parameters.items():
+        if param.kind not in (param.VAR_POSITIONAL, param.VAR_KEYWORD):
+            args2.add(name)
+
+    # print(f"{func2.__name__}{sig2}")
+
+    common = args1.intersection(args2)
+    common.discard("self")
+
+    if common:
+        raise NotImplementedError(
+            f"{func1.__name__}{sig1} and {func2.__name__}{sig2} cannot share the same parameter(s): {common}"
+        )
+
+    spec = inspect.getfullargspec(func1)
 
     args_1 = []
     kwargs_1 = {}
@@ -53,5 +90,5 @@ def consume_args(func, *args, **kwargs):
         if a in kwargs:
             kwargs_1[a] = kwargs.pop(a)
 
-    # print(args_1, kwargs_1, args, kwargs)
+    # print('<=====', args_1, kwargs_1, args, kwargs)
     return args_1, kwargs_1, args, kwargs
