@@ -87,7 +87,7 @@ def _mars_list(start, end, by):
     return result
 
 
-def to_datetime_list(datetimes):
+def to_datetime_list(datetimes):  # noqa C901
 
     if isinstance(datetimes, str):
         # MARS style lists
@@ -107,7 +107,11 @@ def to_datetime_list(datetimes):
         return to_datetime_list([datetimes])
 
     if isinstance(datetimes, (list, tuple)):
-        if len(datetimes) == 3 and datetimes[1].lower() == "to":
+        if (
+            len(datetimes) == 3
+            and isinstance(datetimes[1], str)
+            and datetimes[1].lower() == "to"
+        ):
             return _mars_list(to_datetime(datetimes[0]), to_datetime(datetimes[2]), 1)
 
         if (
