@@ -38,3 +38,10 @@ def test_example(path):
     full = os.path.join(EXAMPLES, path)
     with open(full) as f:
         exec(f.read(), dict(__file__=full), {})
+
+
+if __name__ == "__main__":
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
