@@ -34,4 +34,7 @@ def test_patterns():
 
 
 if __name__ == "__main__":
-    test_patterns()
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
